==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Visual/projectm/translations/projectm_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="40"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="134"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="134"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="135"/>
        <source>&amp;Show Song Title</source>
        <translation>&amp;Mostrar el título de la canción</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="135"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="136"/>
        <source>&amp;Show Preset Name</source>
        <translation>&amp;Mostrar nombre preprogramado</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="136"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="138"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Preprogramado siguiente</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="138"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="139"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Preprogramado anterior</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="139"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="140"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Preprogramado aleatorio</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="140"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="141"/>
        <source>&amp;Lock Preset</source>
        <translation>&amp;Bloquear preprogramado</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="141"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="143"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="143"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="29"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="49"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Acerca del módulo visual ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Módulo visual Projectm para Qmmp</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Este módulo añade visualización projectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Based on llibrojectM-qt library</source>
        <translation>Basado en la librería llibrojectM-qt</translation>
    </message>
</context>
</TS>

==> qmmp_0.7.1.orig.tar.gz: qmmp-0.7.1/src/plugins/Visual/projectm/translations/projectm_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="40"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="134"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="134"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="135"/>
        <source>&amp;Show Song Title</source>
        <translation>&amp;Mostrar el título de la canción</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="135"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="136"/>
        <source>&amp;Show Preset Name</source>
        <translation>&amp;Mostrar nombre preprogramado</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="136"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="138"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Preprogramado siguiente</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="138"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="139"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Preprogramado anterior</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="139"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="140"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Preprogramado aleatorio</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="140"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="141"/>
        <source>&amp;Lock Preset</source>
        <translation>&amp;Bloquear preprogramado</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="141"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="143"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="143"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="29"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="49"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Acerca del módulo visual ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>Módulo visual Projectm para Qmmp</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Este módulo añade visualización projectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Based on llibrojectM-qt library</source>
        <translation>Basado en la librería llibrojectM-qt</translation>
    </message>
</context>
</TS>
